pub enum Severity {
Warning,
Error,
}Expand description
Describes the severity of a compiler message.
Variants
Warning
Advises the user of a potential problem, but still allows compilation to finish.
Error
Advises the user of a problem that prevents the source from compiling.