RantValue

Enum RantValue 

pub enum RantValue {
    String(RantString),
    Float(f64),
    Int(i64),
    Boolean(bool),
    Function(RantFunctionHandle),
    List(RantListHandle),
    Tuple(RantTupleHandle),
    Map(RantMapHandle),
    Range(RantRange),
    Selector(RantSelectorHandle),
    Nothing,
}
A dynamically-typed Rant value.

Cloning

Calling clone() on a by-ref Rant value type (such as list) will only clone its handle; both copies will point to the same contents.

If you want to shallow-copy a by-ref value, use the shallow_copy method instead.

Variants



String(RantString)

A Rant value of type string. Passed by-value.



Float(f64)

A Rant value of type float. Passed by-value.



Int(i64)

A Rant value of type int. Passed by-value.



Boolean(bool)

A Rant value of type bool. Passed by-value.



Function(RantFunctionHandle)

A Rant value of type function. Passed by-reference.



List(RantListHandle)

A Rant value of type list. Passed by-reference.



Tuple(RantTupleHandle)

A Rant value of type tuple. Passed by-reference.



Map(RantMapHandle)

A Rant value of type map. Passed by-reference.



Range(RantRange)

A Rant value of type range. Passed by-value.



Selector(RantSelectorHandle)

A Rant value of type selector. Passed by-value.



Nothing

A Rant unit value of type nothing. Passed by-value.

Implementations

Source

impl RantValue

pub const NAN: Self

Not a Number (NaN).

pub const INFINITY: Self

Positive infinity.

pub const NEG_INFINITY: Self

Negative infinity.

pub const MIN_FLOAT: Self

The lowest possible finite value for the float type.

pub const MAX_FLOAT: Self

The highest possible finite value for the float type.

pub const EPSILON: Self

The smallest possible float value greater than zero.

pub const MIN_INT: Self

The lowest possible value for the int type.

pub const MAX_INT: Self

The highest possible value for the int type.

pub fn is_nothing(&self) -> bool

Returns true if the value is of type nothing.

pub fn is_nan(&self) -> bool

Returns true if the value is NaN (Not a Number).

pub fn is_callable(&self) -> bool

Returns true if the value is callable (e.g. a function).

Source

impl RantValue

pub fn from_func<P: FromRantArgs, F: 'static + Fn(&mut VM<'_>, P) -> Result<(), RuntimeError>>( func: F, ) -> Self

pub fn to_bool(&self) -> bool

Interprets this value as a boolean value according to Rant’s truthiness rules.

Types are converted as follows:

  1. bool returns itself.
  2. int returns true for any non-zero value; otherwise, false.
  3. float returns true for any normal value; otherwise, false.
  4. empty returns false.
  5. Collections that can be zero-length (string, list, map, range) return true if their length is nonzero; otherwise, false.
  6. All other types return true.
pub fn into_bool_value(self) -> Self

Converts to a Rant bool value.

pub fn into_int_value(self) -> Self

Converts to a Rant int value (or empty if the conversion fails).

pub fn into_float_value(self) -> Self

Converts to a Rant float value (or empty if the conversion fails).

pub fn into_string_value(self) -> Self

Converts to a Rant string value.

pub fn into_list_value(self) -> Self

Converts to a Rant list value.

pub fn into_tuple_value(self) -> Self

Converts to a Rant tuple value.

pub fn len(&self) -> usize

Gets the length of the value.

pub fn is_empty(&self) -> bool

Returns true if the length of the value is 0.

pub fn reversed(&self) -> Self

pub fn shallow_copy(&self) -> Self

Returns a shallow copy of the value.

pub fn get_type(&self) -> RantValueType

Gets the Rant type associated with the value.

pub fn type_name(&self) -> &'static str

Gets the type name of the value.

pub fn slice_get(&self, slice: &Slice) -> ValueSliceResult

pub fn slice_set( &mut self, slice: &Slice, val: RantValue, ) -> ValueSliceSetResult

pub fn is_indexable(&self) -> bool

Indicates whether the value can be indexed into.

pub fn index_get(&self, index: i64) -> ValueIndexResult

Attempts to get a value by index.

pub fn index_set(&mut self, index: i64, val: RantValue) -> ValueIndexSetResult

Attempts to set a value by index.

pub fn key_get(&self, key: &str) -> ValueKeyResult

Attempts to get a value by key.

pub fn key_set(&mut self, key: &str, val: RantValue) -> ValueKeySetResult

Attempts to set a value by key.

Source

impl RantValue

pub fn pow(self, exponent: Self) -> ValueResult<Self>

Raises self to the exponent power.

pub fn abs(self) -> ValueResult<Self>

Calculates the absolute value.

pub fn and(self, rhs: RantValue) -> Self

Calculates the logical AND.

pub fn or(self, rhs: RantValue) -> Self

Calculates the logical OR.

pub fn xor(self, rhs: RantValue) -> Self

Calculates the logical XOR.