RantVar

Enum RantVar 

pub enum RantVar {
    ByVal(RantValue),
    ByValConst(RantValue),
    ByRef(Rc<RefCell<RantValue>>),
    ByRefConst(Rc<RantValue>),
}
Represents a Rant variable of one of two flavors: by-value or by-reference.

Cloning

The Clone implementation for this type does not copy any data in ByRef* variants; it only copies the reference.

Variants



ByVal(RantValue)

By-value variable



ByValConst(RantValue)

By-value constant



ByRef(Rc<RefCell<RantValue>>)

By-ref variable



ByRefConst(Rc<RantValue>)

By-ref constant

Implementations

Source

impl RantVar

pub fn is_const(&self) -> bool

Returns true if the variable is a constant.

pub fn is_by_val(&self) -> bool

Returns true if the variable is by-value.

pub fn is_by_ref(&self) -> bool

Returns true if the variable is by-reference.

pub fn make_by_ref(&mut self)

Converts the variable to its by-reference counterpart.

pub fn write(&mut self, value: RantValue) -> bool

Attempts to write the specified value to the variable. If the variable is a constant, returns false; otherwise, returns true.

pub fn value_ref(&self) -> impl Deref<Target = RantValue> + '_

Returns an immutable reference to the contained value.

pub fn value_cloned(&self) -> RantValue

Returns a copy of the variable value.