RantOrderedCollection

Struct RantOrderedCollection 

pub struct RantOrderedCollection(/* private fields */);
Filter type that represents any indexable (ordered) Rant collection type.

Use on native functions to accept any ordered collection type. Derefs to RantValue.

Methods from Deref<Target = RantValue>

pub const NAN: Self

pub const INFINITY: Self

pub const NEG_INFINITY: Self

pub const MIN_FLOAT: Self

pub const MAX_FLOAT: Self

pub const EPSILON: Self

pub const MIN_INT: Self

pub const MAX_INT: Self

pub fn is_nothing(&self) -> bool

Returns true if the value is of type nothing.

pub fn is_nan(&self) -> bool

Returns true if the value is NaN (Not a Number).

pub fn is_callable(&self) -> bool

Returns true if the value is callable (e.g. a function).

pub fn to_bool(&self) -> bool

Interprets this value as a boolean value according to Rant’s truthiness rules.

Types are converted as follows:

  1. bool returns itself.
  2. int returns true for any non-zero value; otherwise, false.
  3. float returns true for any normal value; otherwise, false.
  4. empty returns false.
  5. Collections that can be zero-length (string, list, map, range) return true if their length is nonzero; otherwise, false.
  6. All other types return true.
pub fn len(&self) -> usize

Gets the length of the value.

pub fn is_empty(&self) -> bool

Returns true if the length of the value is 0.

pub fn reversed(&self) -> Self

pub fn shallow_copy(&self) -> Self

Returns a shallow copy of the value.

pub fn get_type(&self) -> RantValueType

Gets the Rant type associated with the value.

pub fn type_name(&self) -> &'static str

Gets the type name of the value.

pub fn slice_get(&self, slice: &Slice) -> ValueSliceResult

pub fn is_indexable(&self) -> bool

Indicates whether the value can be indexed into.

pub fn index_get(&self, index: i64) -> ValueIndexResult

Attempts to get a value by index.

pub fn key_get(&self, key: &str) -> ValueKeyResult

Attempts to get a value by key.