RantSelector

Struct RantSelector 

pub struct RantSelector { /* private fields */ }
Represents a Rant selector instance used by the resolver to select block branches.

Implementations

Source

impl RantSelector

pub fn new(mode: SelectorMode) -> Self

Creates a new selector.

pub fn into_handle(self) -> RantSelectorHandle

Converts the instance into a handle.

pub fn mode(&self) -> SelectorMode

The mode assigned to the selector.

pub fn index(&self) -> usize

The next index to be selected.

pub fn count(&self) -> usize

The number of block elements that this selector is initialized for.

A value of 0 indicates that the selector is uninitialized (as selecting over 0 branches is impossible).

pub fn parity(&self) -> bool

Indicates the parity state of the selector. Some selectors use two alternating passes (such as mirror modes). The parity indicates which of these passes is currently active.

pub fn is_frozen(&self) -> bool

Indicates whether the selector is frozen.

pub fn set_frozen(&mut self, frozen: bool)

Sets the frozen state of the selector.

pub fn is_initialized(&self) -> bool

Indicates whether the selector has been initialized with [Selector::init].

pub fn init( &mut self, rng: &RantRng, elem_count: usize, ) -> Result<(), SelectorError>

Initializes the selector state using the specified element count.

pub fn select( &mut self, elem_count: usize, rng: &RantRng, ) -> Result<usize, SelectorError>

Returns the next branch index and advances the selector state.