TryFromRant

Trait TryFromRant 

pub trait TryFromRant: Sized {
    // Required method
    fn try_from_rant(val: RantValue) -> Result<Self, ValueError>;

    // Provided method
    fn is_optional_param_type() -> bool { ... }
}
Enables fallible conversion from a RantValue.

Required Methods

fn try_from_rant(val: RantValue) -> Result<Self, ValueError>

Convert from a RantValue.

Provided Methods

fn is_optional_param_type() -> bool

Returns true if the type can be used to represent an optional Rant parameter in native functions; otherwise, false.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl TryFromRant for bool

Source

impl TryFromRant for f32

Source

impl TryFromRant for f64

Source

impl TryFromRant for i8

Source

impl TryFromRant for i16

Source

impl TryFromRant for i32

Source

impl TryFromRant for i64

Source

impl TryFromRant for isize

Source

impl TryFromRant for u8

Source

impl TryFromRant for u16

Source

impl TryFromRant for u32

Source

impl TryFromRant for u64

Source

impl TryFromRant for usize

Source

impl TryFromRant for String

Source

impl TryFromRant for CompactString

Source

impl<T: TryFromRant> TryFromRant for Option<T>

Source

impl<T: TryFromRant> TryFromRant for Vec<T>

Implementors