pub type ValueSliceResult = Result<RantValue, SliceError>;Expand description
The result type used by Rant value slice read operations.
Aliased Type
pub enum ValueSliceResult {
Ok(RantValue),
Err(SliceError),
}pub type ValueSliceResult = Result<RantValue, SliceError>;The result type used by Rant value slice read operations.
pub enum ValueSliceResult {
Ok(RantValue),
Err(SliceError),
}