pub struct RantSelector { /* private fields */ }Expand description
Represents a Rant selector instance used by the resolver to select block branches.
Implementations
Sourceimpl RantSelector
impl RantSelector
Sourcepub fn new(mode: SelectorMode) -> Self
pub fn new(mode: SelectorMode) -> Self
Creates a new selector.
Sourcepub fn into_handle(self) -> RantSelectorHandle
pub fn into_handle(self) -> RantSelectorHandle
Converts the instance into a handle.
Sourcepub fn mode(&self) -> SelectorMode
pub fn mode(&self) -> SelectorMode
The mode assigned to the selector.
Sourcepub fn count(&self) -> usize
pub fn count(&self) -> usize
The number of block elements that this selector is initialized for.
A value of 0 indicates that the selector is uninitialized (as selecting over 0 branches is impossible).
Sourcepub fn parity(&self) -> bool
pub fn parity(&self) -> bool
Indicates the parity state of the selector. Some selectors use two alternating passes (such as mirror modes). The parity indicates which of these passes is currently active.
Sourcepub fn set_frozen(&mut self, frozen: bool)
pub fn set_frozen(&mut self, frozen: bool)
Sets the frozen state of the selector.
Sourcepub fn is_initialized(&self) -> bool
pub fn is_initialized(&self) -> bool
Indicates whether the selector has been initialized with [Selector::init].