pub trait TryFromRant: Sized {
// Required method
fn try_from_rant(val: RantValue) -> Result<Self, ValueError>;
// Provided method
fn is_optional_param_type() -> bool { ... }
}Expand description
Enables fallible conversion from a RantValue.
Required Methods
Sourcefn try_from_rant(val: RantValue) -> Result<Self, ValueError>
fn try_from_rant(val: RantValue) -> Result<Self, ValueError>
Convert from a RantValue.
Provided Methods
Sourcefn is_optional_param_type() -> bool
fn is_optional_param_type() -> bool
Returns true if the type can be used to represent an optional Rant parameter in native functions; otherwise, false.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.